[Commits] (bkirsch) Added a mail message generation routine to
comon.py
commits at osafoundation.org
commits at osafoundation.org
Wed Aug 11 16:37:59 PDT 2004
Commit by: bkirsch
Modified files:
chandler/parcels/osaf/mail/common.py 1.1 1.2
Log message:
Added a mail message generation routine to comon.py
ViewCVS links:
http://cvs.osafoundation.org/index.cgi/chandler/parcels/osaf/mail/common.py.diff?r1=text&tr1=1.1&r2=text&tr2=1.2
Index: chandler/parcels/osaf/mail/common.py
diff -u chandler/parcels/osaf/mail/common.py:1.1 chandler/parcels/osaf/mail/common.py:1.2
--- chandler/parcels/osaf/mail/common.py:1.1 Tue Aug 3 16:47:57 2004
+++ chandler/parcels/osaf/mail/common.py Wed Aug 11 16:37:58 2004
@@ -1,6 +1,23 @@
-__revision__ = "$Revision: 1.1 $"
-__date__ = "$Date: 2004/08/03 23:47:57 $"
+__revision__ = "$Revision: 1.2 $"
+__date__ = "$Date: 2004/08/11 23:37:58 $"
__copyright__ = "Copyright (c) 2004 Open Source Applications Foundation"
__license__ = "http://osafoundation.org/Chandler_0.1_license_terms.htm"
-""" Contains functionality shared across the Mail Domain (SMTP, IMAP4, POP3) """
+""" Contains common functionality shared across the Mail Domain (SMTP, IMAP4, POP3) """
+
+
+import email as email
+import email.Message as Message
+import email.Utils as Utils
+
+
+def getChandlerTransportMessage():
+ message = """Subject: ***FOR CHANDLER INTERNAL USE - DO NOT DELETE ***
+
+ This message is used for Chandler to Chandler communication and is
+ not intended to be viewed by the user. Please do not delete this message
+ as Chandler will manage this email automatically for you.
+
+ """
+
+ return email.message_from_string(message)
More information about the Commits
mailing list